pub fn hooks_commit_msg(
repo: &Repository,
other_paths: Option<&[&str]>,
msg: &mut String,
) -> Result<HookResult, HooksError>Expand description
we use the same convention as other git clients to create a temp file containing
pub fn hooks_commit_msg(
repo: &Repository,
other_paths: Option<&[&str]>,
msg: &mut String,
) -> Result<HookResult, HooksError>we use the same convention as other git clients to create a temp file containing